import Vue from 'vue'
import Vuex from 'vuex'
import calculator from './modules/calculator'
import form from './modules/form'
import styles from './modules/styles'

Vue.use(Vuex)

export default new Vuex.Store({
  modules: {
    calculator,
    form,
    styles
  },
  // 根级别的getters，用于兼容旧代码
  getters: {
    // 计算器相关的getter
    calculatorHistory: state => state.calculator.history,
    calculatorInitialValue: state => state.calculator.initialValue,
    calculatorPrecision: state => state.calculator.precision,
    calculatorLastResult: state => state.calculator.lastResult,
    
    // 表单相关的getter
    formSubmittedData: state => state.form.submittedData,
    formSubmissionCount: state => state.form.submissionCount,
    
    // 动态样式相关的getter
    buttonClickData: state => state.styles.buttonClickData,
    buttonClickCount: state => state.styles.clickCount,
    currentTheme: state => state.styles.theme
  },
  // 根级别的actions，用于兼容旧代码
  actions: {
    // 计算器相关的actions
    addCalculationHistory({ dispatch }, operation) {
      dispatch('calculator/addHistory', operation);
    },
    clearCalculationHistory({ dispatch }) {
      dispatch('calculator/clearHistory');
    },
    setCalculatorInitialValue({ dispatch }, value) {
      dispatch('calculator/setInitialValue', value);
    },
    setCalculatorPrecision({ dispatch }, precision) {
      dispatch('calculator/setPrecision', precision);
    },
    handleCalculation({ dispatch }, data) {
      dispatch('calculator/handleCalculation', data);
    },
    
    // 表单相关的actions
    submitFormData({ dispatch }, data) {
      dispatch('form/submitData', data);
    },
    
    // 动态样式相关的actions
    recordButtonClick({ dispatch }, data) {
      dispatch('styles/recordButtonClick', data);
    },
    toggleTheme({ dispatch }) {
      dispatch('styles/toggleTheme');
    }
  }
})
